@@ -48,4 +48,10 @@ class ModelDiffTestCase(TestCase):
         tm.save()
         tm.number = '2'
 
-        self.assertDictEqual(tm._get_diff(), {"number": (1, 2)})
+        self.assertDictEqual({"number": (1, 2)}, tm._get_diff(), )
+
+    def test_jsonfield_change(self):
+        tm = TestDiff(a_json_field={"hi": "bye"})
+        tm.save()
+        self.assertFalse(tm.has_changed)
+
