@@ -37,13 +37,13 @@ class ModelDiffMixin(object):
         return model_to_dict(self, fields=[field.name for field in self._meta.fields])
 
     def _get_diff(self):
+        diffs = []
         d1 = self.__initial
         d2 = self._get_model_dict()
 
-        diffs = []
         for k, v in d1.items():
             f = self._meta.get_field(k)
-            v2 = f.get_prep_value(d2[k])
+            v2 = f.to_python(d2[k])
             if v != v2:
                 diffs.append((k, (v, v2)))
 
